# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.files.configuration import Configuration


class FileUpdateInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"access": "str", "parent_folder_id": "str", "name": "str", "parent_folder_path": "str", "clear_expires": "bool", "is_usable_in_content": "bool", "expires_at": "datetime"}

    attribute_map = {
        "access": "access",
        "parent_folder_id": "parentFolderId",
        "name": "name",
        "parent_folder_path": "parentFolderPath",
        "clear_expires": "clearExpires",
        "is_usable_in_content": "isUsableInContent",
        "expires_at": "expiresAt",
    }

    def __init__(
        self, access=None, parent_folder_id=None, name=None, parent_folder_path=None, clear_expires=None, is_usable_in_content=None, expires_at=None, local_vars_configuration=None
    ):  # noqa: E501
        """FileUpdateInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access = None
        self._parent_folder_id = None
        self._name = None
        self._parent_folder_path = None
        self._clear_expires = None
        self._is_usable_in_content = None
        self._expires_at = None
        self.discriminator = None

        if access is not None:
            self.access = access
        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if name is not None:
            self.name = name
        if parent_folder_path is not None:
            self.parent_folder_path = parent_folder_path
        if clear_expires is not None:
            self.clear_expires = clear_expires
        if is_usable_in_content is not None:
            self.is_usable_in_content = is_usable_in_content
        if expires_at is not None:
            self.expires_at = expires_at

    @property
    def access(self):
        """Gets the access of this FileUpdateInput.  # noqa: E501

        NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.   # noqa: E501

        :return: The access of this FileUpdateInput.  # noqa: E501
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this FileUpdateInput.

        NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.   # noqa: E501

        :param access: The access of this FileUpdateInput.  # noqa: E501
        :type access: str
        """
        allowed_values = ["PUBLIC_INDEXABLE", "PUBLIC_NOT_INDEXABLE", "HIDDEN_INDEXABLE", "HIDDEN_NOT_INDEXABLE", "HIDDEN_PRIVATE", "PRIVATE", "HIDDEN_SENSITIVE", "SENSITIVE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and access not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `access` ({0}), must be one of {1}".format(access, allowed_values))  # noqa: E501

        self._access = access

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this FileUpdateInput.  # noqa: E501

        FolderId where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.  # noqa: E501

        :return: The parent_folder_id of this FileUpdateInput.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this FileUpdateInput.

        FolderId where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this FileUpdateInput.  # noqa: E501
        :type parent_folder_id: str
        """

        self._parent_folder_id = parent_folder_id

    @property
    def name(self):
        """Gets the name of this FileUpdateInput.  # noqa: E501

        New name for the file.  # noqa: E501

        :return: The name of this FileUpdateInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileUpdateInput.

        New name for the file.  # noqa: E501

        :param name: The name of this FileUpdateInput.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def parent_folder_path(self):
        """Gets the parent_folder_path of this FileUpdateInput.  # noqa: E501

        Folder path where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.  # noqa: E501

        :return: The parent_folder_path of this FileUpdateInput.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_path

    @parent_folder_path.setter
    def parent_folder_path(self, parent_folder_path):
        """Sets the parent_folder_path of this FileUpdateInput.

        Folder path where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.  # noqa: E501

        :param parent_folder_path: The parent_folder_path of this FileUpdateInput.  # noqa: E501
        :type parent_folder_path: str
        """

        self._parent_folder_path = parent_folder_path

    @property
    def clear_expires(self):
        """Gets the clear_expires of this FileUpdateInput.  # noqa: E501


        :return: The clear_expires of this FileUpdateInput.  # noqa: E501
        :rtype: bool
        """
        return self._clear_expires

    @clear_expires.setter
    def clear_expires(self, clear_expires):
        """Sets the clear_expires of this FileUpdateInput.


        :param clear_expires: The clear_expires of this FileUpdateInput.  # noqa: E501
        :type clear_expires: bool
        """

        self._clear_expires = clear_expires

    @property
    def is_usable_in_content(self):
        """Gets the is_usable_in_content of this FileUpdateInput.  # noqa: E501

        Mark whether the file should be used in new content or not.  # noqa: E501

        :return: The is_usable_in_content of this FileUpdateInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_usable_in_content

    @is_usable_in_content.setter
    def is_usable_in_content(self, is_usable_in_content):
        """Sets the is_usable_in_content of this FileUpdateInput.

        Mark whether the file should be used in new content or not.  # noqa: E501

        :param is_usable_in_content: The is_usable_in_content of this FileUpdateInput.  # noqa: E501
        :type is_usable_in_content: bool
        """

        self._is_usable_in_content = is_usable_in_content

    @property
    def expires_at(self):
        """Gets the expires_at of this FileUpdateInput.  # noqa: E501


        :return: The expires_at of this FileUpdateInput.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this FileUpdateInput.


        :param expires_at: The expires_at of this FileUpdateInput.  # noqa: E501
        :type expires_at: datetime
        """

        self._expires_at = expires_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileUpdateInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileUpdateInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Imports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.imports.configuration import Configuration


class ImportRowCore(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"row_data": "list[str]", "contains_encrypted_properties": "bool", "line_number": "int", "page_name": "str", "file_id": "int"}

    attribute_map = {"row_data": "rowData", "contains_encrypted_properties": "containsEncryptedProperties", "line_number": "lineNumber", "page_name": "pageName", "file_id": "fileId"}

    def __init__(self, row_data=None, contains_encrypted_properties=None, line_number=None, page_name=None, file_id=None, local_vars_configuration=None):  # noqa: E501
        """ImportRowCore - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._row_data = None
        self._contains_encrypted_properties = None
        self._line_number = None
        self._page_name = None
        self._file_id = None
        self.discriminator = None

        self.row_data = row_data
        self.contains_encrypted_properties = contains_encrypted_properties
        self.line_number = line_number
        if page_name is not None:
            self.page_name = page_name
        self.file_id = file_id

    @property
    def row_data(self):
        """Gets the row_data of this ImportRowCore.  # noqa: E501


        :return: The row_data of this ImportRowCore.  # noqa: E501
        :rtype: list[str]
        """
        return self._row_data

    @row_data.setter
    def row_data(self, row_data):
        """Sets the row_data of this ImportRowCore.


        :param row_data: The row_data of this ImportRowCore.  # noqa: E501
        :type row_data: list[str]
        """
        if self.local_vars_configuration.client_side_validation and row_data is None:  # noqa: E501
            raise ValueError("Invalid value for `row_data`, must not be `None`")  # noqa: E501

        self._row_data = row_data

    @property
    def contains_encrypted_properties(self):
        """Gets the contains_encrypted_properties of this ImportRowCore.  # noqa: E501


        :return: The contains_encrypted_properties of this ImportRowCore.  # noqa: E501
        :rtype: bool
        """
        return self._contains_encrypted_properties

    @contains_encrypted_properties.setter
    def contains_encrypted_properties(self, contains_encrypted_properties):
        """Sets the contains_encrypted_properties of this ImportRowCore.


        :param contains_encrypted_properties: The contains_encrypted_properties of this ImportRowCore.  # noqa: E501
        :type contains_encrypted_properties: bool
        """
        if self.local_vars_configuration.client_side_validation and contains_encrypted_properties is None:  # noqa: E501
            raise ValueError("Invalid value for `contains_encrypted_properties`, must not be `None`")  # noqa: E501

        self._contains_encrypted_properties = contains_encrypted_properties

    @property
    def line_number(self):
        """Gets the line_number of this ImportRowCore.  # noqa: E501


        :return: The line_number of this ImportRowCore.  # noqa: E501
        :rtype: int
        """
        return self._line_number

    @line_number.setter
    def line_number(self, line_number):
        """Sets the line_number of this ImportRowCore.


        :param line_number: The line_number of this ImportRowCore.  # noqa: E501
        :type line_number: int
        """
        if self.local_vars_configuration.client_side_validation and line_number is None:  # noqa: E501
            raise ValueError("Invalid value for `line_number`, must not be `None`")  # noqa: E501

        self._line_number = line_number

    @property
    def page_name(self):
        """Gets the page_name of this ImportRowCore.  # noqa: E501


        :return: The page_name of this ImportRowCore.  # noqa: E501
        :rtype: str
        """
        return self._page_name

    @page_name.setter
    def page_name(self, page_name):
        """Sets the page_name of this ImportRowCore.


        :param page_name: The page_name of this ImportRowCore.  # noqa: E501
        :type page_name: str
        """

        self._page_name = page_name

    @property
    def file_id(self):
        """Gets the file_id of this ImportRowCore.  # noqa: E501


        :return: The file_id of this ImportRowCore.  # noqa: E501
        :rtype: int
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this ImportRowCore.


        :param file_id: The file_id of this ImportRowCore.  # noqa: E501
        :type file_id: int
        """
        if self.local_vars_configuration.client_side_validation and file_id is None:  # noqa: E501
            raise ValueError("Invalid value for `file_id`, must not be `None`")  # noqa: E501

        self._file_id = file_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportRowCore):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportRowCore):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Crm Owners

    HubSpot uses **owners** to assign CRM objects to specific people in your organization. The endpoints described here are used to get a list of the owners that are available for an account. To assign an owner to an object, set the hubspot_owner_id property using the appropriate CRM object update or create a request.  If teams are available for your HubSpot tier, these endpoints will also indicate which team(s) an owner can access, as well as which team is the owner's primary team.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.owners.models.collection_response_public_owner_forward_paging import CollectionResponsePublicOwnerForwardPaging
from hubspot.crm.owners.models.error import Error
from hubspot.crm.owners.models.error_detail import ErrorDetail
from hubspot.crm.owners.models.forward_paging import ForwardPaging
from hubspot.crm.owners.models.next_page import NextPage
from hubspot.crm.owners.models.public_owner import PublicOwner
from hubspot.crm.owners.models.public_team import PublicTeam



# coding: utf-8

"""
    Posts

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.blogs.blog_posts.configuration import Configuration


class LayoutSection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "css_style": "str",
        "label": "str",
        "type": "str",
        "params": "dict[str, object]",
        "rows": "list[dict[str, LayoutSection]]",
        "row_meta_data": "list[RowMetaData]",
        "cells": "list[LayoutSection]",
        "css_class": "str",
        "w": "int",
        "css_id": "str",
        "x": "int",
        "name": "str",
        "styles": "Styles",
    }

    attribute_map = {
        "css_style": "cssStyle",
        "label": "label",
        "type": "type",
        "params": "params",
        "rows": "rows",
        "row_meta_data": "rowMetaData",
        "cells": "cells",
        "css_class": "cssClass",
        "w": "w",
        "css_id": "cssId",
        "x": "x",
        "name": "name",
        "styles": "styles",
    }

    def __init__(
        self,
        css_style=None,
        label=None,
        type=None,
        params=None,
        rows=None,
        row_meta_data=None,
        cells=None,
        css_class=None,
        w=None,
        css_id=None,
        x=None,
        name=None,
        styles=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """LayoutSection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._css_style = None
        self._label = None
        self._type = None
        self._params = None
        self._rows = None
        self._row_meta_data = None
        self._cells = None
        self._css_class = None
        self._w = None
        self._css_id = None
        self._x = None
        self._name = None
        self._styles = None
        self.discriminator = None

        self.css_style = css_style
        self.label = label
        self.type = type
        self.params = params
        self.rows = rows
        self.row_meta_data = row_meta_data
        self.cells = cells
        self.css_class = css_class
        self.w = w
        self.css_id = css_id
        self.x = x
        self.name = name
        self.styles = styles

    @property
    def css_style(self):
        """Gets the css_style of this LayoutSection.  # noqa: E501


        :return: The css_style of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._css_style

    @css_style.setter
    def css_style(self, css_style):
        """Sets the css_style of this LayoutSection.


        :param css_style: The css_style of this LayoutSection.  # noqa: E501
        :type css_style: str
        """
        if self.local_vars_configuration.client_side_validation and css_style is None:  # noqa: E501
            raise ValueError("Invalid value for `css_style`, must not be `None`")  # noqa: E501

        self._css_style = css_style

    @property
    def label(self):
        """Gets the label of this LayoutSection.  # noqa: E501


        :return: The label of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this LayoutSection.


        :param label: The label of this LayoutSection.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def type(self):
        """Gets the type of this LayoutSection.  # noqa: E501


        :return: The type of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LayoutSection.


        :param type: The type of this LayoutSection.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def params(self):
        """Gets the params of this LayoutSection.  # noqa: E501

        null  # noqa: E501

        :return: The params of this LayoutSection.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this LayoutSection.

        null  # noqa: E501

        :param params: The params of this LayoutSection.  # noqa: E501
        :type params: dict[str, object]
        """
        if self.local_vars_configuration.client_side_validation and params is None:  # noqa: E501
            raise ValueError("Invalid value for `params`, must not be `None`")  # noqa: E501

        self._params = params

    @property
    def rows(self):
        """Gets the rows of this LayoutSection.  # noqa: E501


        :return: The rows of this LayoutSection.  # noqa: E501
        :rtype: list[dict[str, LayoutSection]]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """Sets the rows of this LayoutSection.


        :param rows: The rows of this LayoutSection.  # noqa: E501
        :type rows: list[dict[str, LayoutSection]]
        """
        if self.local_vars_configuration.client_side_validation and rows is None:  # noqa: E501
            raise ValueError("Invalid value for `rows`, must not be `None`")  # noqa: E501

        self._rows = rows

    @property
    def row_meta_data(self):
        """Gets the row_meta_data of this LayoutSection.  # noqa: E501


        :return: The row_meta_data of this LayoutSection.  # noqa: E501
        :rtype: list[RowMetaData]
        """
        return self._row_meta_data

    @row_meta_data.setter
    def row_meta_data(self, row_meta_data):
        """Sets the row_meta_data of this LayoutSection.


        :param row_meta_data: The row_meta_data of this LayoutSection.  # noqa: E501
        :type row_meta_data: list[RowMetaData]
        """
        if self.local_vars_configuration.client_side_validation and row_meta_data is None:  # noqa: E501
            raise ValueError("Invalid value for `row_meta_data`, must not be `None`")  # noqa: E501

        self._row_meta_data = row_meta_data

    @property
    def cells(self):
        """Gets the cells of this LayoutSection.  # noqa: E501


        :return: The cells of this LayoutSection.  # noqa: E501
        :rtype: list[LayoutSection]
        """
        return self._cells

    @cells.setter
    def cells(self, cells):
        """Sets the cells of this LayoutSection.


        :param cells: The cells of this LayoutSection.  # noqa: E501
        :type cells: list[LayoutSection]
        """
        if self.local_vars_configuration.client_side_validation and cells is None:  # noqa: E501
            raise ValueError("Invalid value for `cells`, must not be `None`")  # noqa: E501

        self._cells = cells

    @property
    def css_class(self):
        """Gets the css_class of this LayoutSection.  # noqa: E501


        :return: The css_class of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._css_class

    @css_class.setter
    def css_class(self, css_class):
        """Sets the css_class of this LayoutSection.


        :param css_class: The css_class of this LayoutSection.  # noqa: E501
        :type css_class: str
        """
        if self.local_vars_configuration.client_side_validation and css_class is None:  # noqa: E501
            raise ValueError("Invalid value for `css_class`, must not be `None`")  # noqa: E501

        self._css_class = css_class

    @property
    def w(self):
        """Gets the w of this LayoutSection.  # noqa: E501


        :return: The w of this LayoutSection.  # noqa: E501
        :rtype: int
        """
        return self._w

    @w.setter
    def w(self, w):
        """Sets the w of this LayoutSection.


        :param w: The w of this LayoutSection.  # noqa: E501
        :type w: int
        """
        if self.local_vars_configuration.client_side_validation and w is None:  # noqa: E501
            raise ValueError("Invalid value for `w`, must not be `None`")  # noqa: E501

        self._w = w

    @property
    def css_id(self):
        """Gets the css_id of this LayoutSection.  # noqa: E501


        :return: The css_id of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._css_id

    @css_id.setter
    def css_id(self, css_id):
        """Sets the css_id of this LayoutSection.


        :param css_id: The css_id of this LayoutSection.  # noqa: E501
        :type css_id: str
        """
        if self.local_vars_configuration.client_side_validation and css_id is None:  # noqa: E501
            raise ValueError("Invalid value for `css_id`, must not be `None`")  # noqa: E501

        self._css_id = css_id

    @property
    def x(self):
        """Gets the x of this LayoutSection.  # noqa: E501


        :return: The x of this LayoutSection.  # noqa: E501
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this LayoutSection.


        :param x: The x of this LayoutSection.  # noqa: E501
        :type x: int
        """
        if self.local_vars_configuration.client_side_validation and x is None:  # noqa: E501
            raise ValueError("Invalid value for `x`, must not be `None`")  # noqa: E501

        self._x = x

    @property
    def name(self):
        """Gets the name of this LayoutSection.  # noqa: E501


        :return: The name of this LayoutSection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LayoutSection.


        :param name: The name of this LayoutSection.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def styles(self):
        """Gets the styles of this LayoutSection.  # noqa: E501


        :return: The styles of this LayoutSection.  # noqa: E501
        :rtype: Styles
        """
        return self._styles

    @styles.setter
    def styles(self, styles):
        """Sets the styles of this LayoutSection.


        :param styles: The styles of this LayoutSection.  # noqa: E501
        :type styles: Styles
        """
        if self.local_vars_configuration.client_side_validation and styles is None:  # noqa: E501
            raise ValueError("Invalid value for `styles`, must not be `None`")  # noqa: E501

        self._styles = styles

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LayoutSection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LayoutSection):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.conversations.conversations as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def actors_api(self) -> api_client.ActorsApi:
        return self._configure_api_client(api_client, "ActorsApi")

    @property
    def channel_accounts_api(self) -> api_client.ChannelAccountsApi:
        return self._configure_api_client(api_client, "ChannelAccountsApi")

    @property
    def channels_api(self) -> api_client.ChannelsApi:
        return self._configure_api_client(api_client, "ChannelsApi")

    @property
    def inboxes_api(self) -> api_client.InboxesApi:
        return self._configure_api_client(api_client, "InboxesApi")

    @property
    def threads_api(self) -> api_client.ThreadsApi:
        return self._configure_api_client(api_client, "ThreadsApi")



# coding: utf-8

# flake8: noqa

"""
    CMS Url Redirects

    URL redirect operations  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.url_redirects.api.redirects_api import RedirectsApi

# import ApiClient
from hubspot.cms.url_redirects.api_client import ApiClient
from hubspot.cms.url_redirects.configuration import Configuration
from hubspot.cms.url_redirects.exceptions import OpenApiException
from hubspot.cms.url_redirects.exceptions import ApiTypeError
from hubspot.cms.url_redirects.exceptions import ApiValueError
from hubspot.cms.url_redirects.exceptions import ApiKeyError
from hubspot.cms.url_redirects.exceptions import ApiAttributeError
from hubspot.cms.url_redirects.exceptions import ApiException

# import models into sdk package
from hubspot.cms.url_redirects.models.collection_response_with_total_url_mapping_forward_paging import CollectionResponseWithTotalUrlMappingForwardPaging
from hubspot.cms.url_redirects.models.error import Error
from hubspot.cms.url_redirects.models.error_detail import ErrorDetail
from hubspot.cms.url_redirects.models.forward_paging import ForwardPaging
from hubspot.cms.url_redirects.models.next_page import NextPage
from hubspot.cms.url_redirects.models.url_mapping import UrlMapping
from hubspot.cms.url_redirects.models.url_mapping_create_request_body import UrlMappingCreateRequestBody



class Auth:
    @staticmethod
    def get_auth_types() -> list:
        return ["access_token", "api_key"]

    @staticmethod
    def _has_auth_value(source: dict, key: str) -> bool:
        return bool(source.get(key))

    @staticmethod
    def choose_auth(config: dict, options: dict) -> dict:
        auth_types = Auth.get_auth_types()
        auth_type = options.get("auth_type")

        if auth_type in auth_types and Auth._has_auth_value(config, auth_type):
            return {"auth_type": auth_type}

        else:
            for key in auth_types:
                if key in config and Auth._has_auth_value(config, key):
                    return {"auth_type": key}

        return {"auth_type": None}




# coding: utf-8

# flake8: noqa

"""
    Pages

    Use these endpoints for interacting with Landing Pages and Site Pages  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.pages.api.landing_pages_api import LandingPagesApi
from hubspot.cms.pages.api.site_pages_api import SitePagesApi

# import ApiClient
from hubspot.cms.pages.api_client import ApiClient
from hubspot.cms.pages.configuration import Configuration
from hubspot.cms.pages.exceptions import OpenApiException
from hubspot.cms.pages.exceptions import ApiTypeError
from hubspot.cms.pages.exceptions import ApiValueError
from hubspot.cms.pages.exceptions import ApiKeyError
from hubspot.cms.pages.exceptions import ApiAttributeError
from hubspot.cms.pages.exceptions import ApiException

# import models into sdk package
from hubspot.cms.pages.models.ab_test_create_request_v_next import AbTestCreateRequestVNext
from hubspot.cms.pages.models.ab_test_end_request_v_next import AbTestEndRequestVNext
from hubspot.cms.pages.models.ab_test_rerun_request_v_next import AbTestRerunRequestVNext
from hubspot.cms.pages.models.angle import Angle
from hubspot.cms.pages.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.pages.models.background_image import BackgroundImage
from hubspot.cms.pages.models.batch_input_content_folder import BatchInputContentFolder
from hubspot.cms.pages.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.pages.models.batch_input_page import BatchInputPage
from hubspot.cms.pages.models.batch_input_string import BatchInputString
from hubspot.cms.pages.models.batch_response_content_folder import BatchResponseContentFolder
from hubspot.cms.pages.models.batch_response_content_folder_with_errors import BatchResponseContentFolderWithErrors
from hubspot.cms.pages.models.batch_response_page import BatchResponsePage
from hubspot.cms.pages.models.batch_response_page_with_errors import BatchResponsePageWithErrors
from hubspot.cms.pages.models.collection_response_with_total_content_folder_forward_paging import CollectionResponseWithTotalContentFolderForwardPaging
from hubspot.cms.pages.models.collection_response_with_total_page_forward_paging import CollectionResponseWithTotalPageForwardPaging
from hubspot.cms.pages.models.collection_response_with_total_version_content_folder import CollectionResponseWithTotalVersionContentFolder
from hubspot.cms.pages.models.collection_response_with_total_version_page import CollectionResponseWithTotalVersionPage
from hubspot.cms.pages.models.color_stop import ColorStop
from hubspot.cms.pages.models.content_clone_request_v_next import ContentCloneRequestVNext
from hubspot.cms.pages.models.content_folder import ContentFolder
from hubspot.cms.pages.models.content_language_clone_request_v_next import ContentLanguageCloneRequestVNext
from hubspot.cms.pages.models.content_language_variation import ContentLanguageVariation
from hubspot.cms.pages.models.content_schedule_request_v_next import ContentScheduleRequestVNext
from hubspot.cms.pages.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.pages.models.error import Error
from hubspot.cms.pages.models.error_detail import ErrorDetail
from hubspot.cms.pages.models.forward_paging import ForwardPaging
from hubspot.cms.pages.models.gradient import Gradient
from hubspot.cms.pages.models.layout_section import LayoutSection
from hubspot.cms.pages.models.next_page import NextPage
from hubspot.cms.pages.models.page import Page
from hubspot.cms.pages.models.paging import Paging
from hubspot.cms.pages.models.previous_page import PreviousPage
from hubspot.cms.pages.models.rgba_color import RGBAColor
from hubspot.cms.pages.models.row_meta_data import RowMetaData
from hubspot.cms.pages.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.pages.models.side_or_corner import SideOrCorner
from hubspot.cms.pages.models.standard_error import StandardError
from hubspot.cms.pages.models.styles import Styles
from hubspot.cms.pages.models.update_languages_request_v_next import UpdateLanguagesRequestVNext
from hubspot.cms.pages.models.version_content_folder import VersionContentFolder
from hubspot.cms.pages.models.version_page import VersionPage
from hubspot.cms.pages.models.version_user import VersionUser



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class ObjectTypePropertyCreate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "hidden": "bool",
        "option_sort_strategy": "str",
        "display_order": "int",
        "description": "str",
        "show_currency_symbol": "bool",
        "label": "str",
        "type": "str",
        "form_field": "bool",
        "group_name": "str",
        "referenced_object_type": "str",
        "text_display_hint": "str",
        "name": "str",
        "options": "list[OptionInput]",
        "searchable_in_global_search": "bool",
        "number_display_hint": "str",
        "has_unique_value": "bool",
        "field_type": "str",
    }

    attribute_map = {
        "hidden": "hidden",
        "option_sort_strategy": "optionSortStrategy",
        "display_order": "displayOrder",
        "description": "description",
        "show_currency_symbol": "showCurrencySymbol",
        "label": "label",
        "type": "type",
        "form_field": "formField",
        "group_name": "groupName",
        "referenced_object_type": "referencedObjectType",
        "text_display_hint": "textDisplayHint",
        "name": "name",
        "options": "options",
        "searchable_in_global_search": "searchableInGlobalSearch",
        "number_display_hint": "numberDisplayHint",
        "has_unique_value": "hasUniqueValue",
        "field_type": "fieldType",
    }

    def __init__(
        self,
        hidden=None,
        option_sort_strategy=None,
        display_order=None,
        description=None,
        show_currency_symbol=None,
        label=None,
        type=None,
        form_field=None,
        group_name=None,
        referenced_object_type=None,
        text_display_hint=None,
        name=None,
        options=None,
        searchable_in_global_search=None,
        number_display_hint=None,
        has_unique_value=None,
        field_type=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ObjectTypePropertyCreate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hidden = None
        self._option_sort_strategy = None
        self._display_order = None
        self._description = None
        self._show_currency_symbol = None
        self._label = None
        self._type = None
        self._form_field = None
        self._group_name = None
        self._referenced_object_type = None
        self._text_display_hint = None
        self._name = None
        self._options = None
        self._searchable_in_global_search = None
        self._number_display_hint = None
        self._has_unique_value = None
        self._field_type = None
        self.discriminator = None

        if hidden is not None:
            self.hidden = hidden
        if option_sort_strategy is not None:
            self.option_sort_strategy = option_sort_strategy
        if display_order is not None:
            self.display_order = display_order
        if description is not None:
            self.description = description
        if show_currency_symbol is not None:
            self.show_currency_symbol = show_currency_symbol
        self.label = label
        self.type = type
        if form_field is not None:
            self.form_field = form_field
        if group_name is not None:
            self.group_name = group_name
        if referenced_object_type is not None:
            self.referenced_object_type = referenced_object_type
        if text_display_hint is not None:
            self.text_display_hint = text_display_hint
        self.name = name
        if options is not None:
            self.options = options
        if searchable_in_global_search is not None:
            self.searchable_in_global_search = searchable_in_global_search
        if number_display_hint is not None:
            self.number_display_hint = number_display_hint
        if has_unique_value is not None:
            self.has_unique_value = has_unique_value
        self.field_type = field_type

    @property
    def hidden(self):
        """Gets the hidden of this ObjectTypePropertyCreate.  # noqa: E501


        :return: The hidden of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this ObjectTypePropertyCreate.


        :param hidden: The hidden of this ObjectTypePropertyCreate.  # noqa: E501
        :type hidden: bool
        """

        self._hidden = hidden

    @property
    def option_sort_strategy(self):
        """Gets the option_sort_strategy of this ObjectTypePropertyCreate.  # noqa: E501

        Controls how the property options will be sorted in the HubSpot UI.  # noqa: E501

        :return: The option_sort_strategy of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._option_sort_strategy

    @option_sort_strategy.setter
    def option_sort_strategy(self, option_sort_strategy):
        """Sets the option_sort_strategy of this ObjectTypePropertyCreate.

        Controls how the property options will be sorted in the HubSpot UI.  # noqa: E501

        :param option_sort_strategy: The option_sort_strategy of this ObjectTypePropertyCreate.  # noqa: E501
        :type option_sort_strategy: str
        """
        allowed_values = ["DISPLAY_ORDER", "ALPHABETICAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and option_sort_strategy not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `option_sort_strategy` ({0}), must be one of {1}".format(option_sort_strategy, allowed_values))  # noqa: E501

        self._option_sort_strategy = option_sort_strategy

    @property
    def display_order(self):
        """Gets the display_order of this ObjectTypePropertyCreate.  # noqa: E501

        The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed **after** any positive values.  # noqa: E501

        :return: The display_order of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this ObjectTypePropertyCreate.

        The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed **after** any positive values.  # noqa: E501

        :param display_order: The display_order of this ObjectTypePropertyCreate.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def description(self):
        """Gets the description of this ObjectTypePropertyCreate.  # noqa: E501

        A description of the property that will be shown as help text in HubSpot.  # noqa: E501

        :return: The description of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ObjectTypePropertyCreate.

        A description of the property that will be shown as help text in HubSpot.  # noqa: E501

        :param description: The description of this ObjectTypePropertyCreate.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def show_currency_symbol(self):
        """Gets the show_currency_symbol of this ObjectTypePropertyCreate.  # noqa: E501

        Whether the property will display the currency symbol in the HubSpot UI.  # noqa: E501

        :return: The show_currency_symbol of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: bool
        """
        return self._show_currency_symbol

    @show_currency_symbol.setter
    def show_currency_symbol(self, show_currency_symbol):
        """Sets the show_currency_symbol of this ObjectTypePropertyCreate.

        Whether the property will display the currency symbol in the HubSpot UI.  # noqa: E501

        :param show_currency_symbol: The show_currency_symbol of this ObjectTypePropertyCreate.  # noqa: E501
        :type show_currency_symbol: bool
        """

        self._show_currency_symbol = show_currency_symbol

    @property
    def label(self):
        """Gets the label of this ObjectTypePropertyCreate.  # noqa: E501

        A human-readable property label that will be shown in HubSpot.  # noqa: E501

        :return: The label of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ObjectTypePropertyCreate.

        A human-readable property label that will be shown in HubSpot.  # noqa: E501

        :param label: The label of this ObjectTypePropertyCreate.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def type(self):
        """Gets the type of this ObjectTypePropertyCreate.  # noqa: E501

        The data type of the property.  # noqa: E501

        :return: The type of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ObjectTypePropertyCreate.

        The data type of the property.  # noqa: E501

        :param type: The type of this ObjectTypePropertyCreate.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["string", "number", "date", "datetime", "enumeration", "bool"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def form_field(self):
        """Gets the form_field of this ObjectTypePropertyCreate.  # noqa: E501

        Whether the property can be used in a HubSpot form.  # noqa: E501

        :return: The form_field of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: bool
        """
        return self._form_field

    @form_field.setter
    def form_field(self, form_field):
        """Sets the form_field of this ObjectTypePropertyCreate.

        Whether the property can be used in a HubSpot form.  # noqa: E501

        :param form_field: The form_field of this ObjectTypePropertyCreate.  # noqa: E501
        :type form_field: bool
        """

        self._form_field = form_field

    @property
    def group_name(self):
        """Gets the group_name of this ObjectTypePropertyCreate.  # noqa: E501

        The name of the group this property belongs to.  # noqa: E501

        :return: The group_name of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this ObjectTypePropertyCreate.

        The name of the group this property belongs to.  # noqa: E501

        :param group_name: The group_name of this ObjectTypePropertyCreate.  # noqa: E501
        :type group_name: str
        """

        self._group_name = group_name

    @property
    def referenced_object_type(self):
        """Gets the referenced_object_type of this ObjectTypePropertyCreate.  # noqa: E501

        Defines the options this property will return, e.g. OWNER would return name of users on the portal.  # noqa: E501

        :return: The referenced_object_type of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._referenced_object_type

    @referenced_object_type.setter
    def referenced_object_type(self, referenced_object_type):
        """Sets the referenced_object_type of this ObjectTypePropertyCreate.

        Defines the options this property will return, e.g. OWNER would return name of users on the portal.  # noqa: E501

        :param referenced_object_type: The referenced_object_type of this ObjectTypePropertyCreate.  # noqa: E501
        :type referenced_object_type: str
        """

        self._referenced_object_type = referenced_object_type

    @property
    def text_display_hint(self):
        """Gets the text_display_hint of this ObjectTypePropertyCreate.  # noqa: E501

        Controls how text properties are formatted in the HubSpot UI  # noqa: E501

        :return: The text_display_hint of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._text_display_hint

    @text_display_hint.setter
    def text_display_hint(self, text_display_hint):
        """Sets the text_display_hint of this ObjectTypePropertyCreate.

        Controls how text properties are formatted in the HubSpot UI  # noqa: E501

        :param text_display_hint: The text_display_hint of this ObjectTypePropertyCreate.  # noqa: E501
        :type text_display_hint: str
        """
        allowed_values = ["unformatted_single_line", "multi_line", "email", "phone_number", "domain_name", "ip_address", "physical_address", "postal_code"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and text_display_hint not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `text_display_hint` ({0}), must be one of {1}".format(text_display_hint, allowed_values))  # noqa: E501

        self._text_display_hint = text_display_hint

    @property
    def name(self):
        """Gets the name of this ObjectTypePropertyCreate.  # noqa: E501

        The internal property name, which must be used when referencing the property from the API.  # noqa: E501

        :return: The name of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ObjectTypePropertyCreate.

        The internal property name, which must be used when referencing the property from the API.  # noqa: E501

        :param name: The name of this ObjectTypePropertyCreate.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def options(self):
        """Gets the options of this ObjectTypePropertyCreate.  # noqa: E501

        A list of available options for the property. This field is only required for enumerated properties.  # noqa: E501

        :return: The options of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: list[OptionInput]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this ObjectTypePropertyCreate.

        A list of available options for the property. This field is only required for enumerated properties.  # noqa: E501

        :param options: The options of this ObjectTypePropertyCreate.  # noqa: E501
        :type options: list[OptionInput]
        """

        self._options = options

    @property
    def searchable_in_global_search(self):
        """Gets the searchable_in_global_search of this ObjectTypePropertyCreate.  # noqa: E501

        Allow users to search for information entered to this field (limited to 3 properties)  # noqa: E501

        :return: The searchable_in_global_search of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: bool
        """
        return self._searchable_in_global_search

    @searchable_in_global_search.setter
    def searchable_in_global_search(self, searchable_in_global_search):
        """Sets the searchable_in_global_search of this ObjectTypePropertyCreate.

        Allow users to search for information entered to this field (limited to 3 properties)  # noqa: E501

        :param searchable_in_global_search: The searchable_in_global_search of this ObjectTypePropertyCreate.  # noqa: E501
        :type searchable_in_global_search: bool
        """

        self._searchable_in_global_search = searchable_in_global_search

    @property
    def number_display_hint(self):
        """Gets the number_display_hint of this ObjectTypePropertyCreate.  # noqa: E501

        Controls how numeric properties are formatted in the HubSpot UI  # noqa: E501

        :return: The number_display_hint of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._number_display_hint

    @number_display_hint.setter
    def number_display_hint(self, number_display_hint):
        """Sets the number_display_hint of this ObjectTypePropertyCreate.

        Controls how numeric properties are formatted in the HubSpot UI  # noqa: E501

        :param number_display_hint: The number_display_hint of this ObjectTypePropertyCreate.  # noqa: E501
        :type number_display_hint: str
        """
        allowed_values = ["unformatted", "formatted", "currency", "percentage", "duration", "probability"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and number_display_hint not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `number_display_hint` ({0}), must be one of {1}".format(number_display_hint, allowed_values))  # noqa: E501

        self._number_display_hint = number_display_hint

    @property
    def has_unique_value(self):
        """Gets the has_unique_value of this ObjectTypePropertyCreate.  # noqa: E501

        Whether or not the property's value must be unique. Once set, this can't be changed.  # noqa: E501

        :return: The has_unique_value of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: bool
        """
        return self._has_unique_value

    @has_unique_value.setter
    def has_unique_value(self, has_unique_value):
        """Sets the has_unique_value of this ObjectTypePropertyCreate.

        Whether or not the property's value must be unique. Once set, this can't be changed.  # noqa: E501

        :param has_unique_value: The has_unique_value of this ObjectTypePropertyCreate.  # noqa: E501
        :type has_unique_value: bool
        """

        self._has_unique_value = has_unique_value

    @property
    def field_type(self):
        """Gets the field_type of this ObjectTypePropertyCreate.  # noqa: E501

        Controls how the property appears in HubSpot.  # noqa: E501

        :return: The field_type of this ObjectTypePropertyCreate.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this ObjectTypePropertyCreate.

        Controls how the property appears in HubSpot.  # noqa: E501

        :param field_type: The field_type of this ObjectTypePropertyCreate.  # noqa: E501
        :type field_type: str
        """
        if self.local_vars_configuration.client_side_validation and field_type is None:  # noqa: E501
            raise ValueError("Invalid value for `field_type`, must not be `None`")  # noqa: E501

        self._field_type = field_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectTypePropertyCreate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ObjectTypePropertyCreate):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.crm.properties as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def batch_api(self) -> api_client.BatchApi:
        return self._configure_api_client(api_client, "BatchApi")

    @property
    def core_api(self) -> api_client.CoreApi:
        return self._configure_api_client(api_client, "CoreApi")

    @property
    def groups_api(self) -> api_client.GroupsApi:
        return self._configure_api_client(api_client, "GroupsApi")



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class PropertyModificationMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"read_only_options": "bool", "read_only_value": "bool", "read_only_definition": "bool", "archivable": "bool"}

    attribute_map = {"read_only_options": "readOnlyOptions", "read_only_value": "readOnlyValue", "read_only_definition": "readOnlyDefinition", "archivable": "archivable"}

    def __init__(self, read_only_options=None, read_only_value=None, read_only_definition=None, archivable=None, local_vars_configuration=None):  # noqa: E501
        """PropertyModificationMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._read_only_options = None
        self._read_only_value = None
        self._read_only_definition = None
        self._archivable = None
        self.discriminator = None

        if read_only_options is not None:
            self.read_only_options = read_only_options
        self.read_only_value = read_only_value
        self.read_only_definition = read_only_definition
        self.archivable = archivable

    @property
    def read_only_options(self):
        """Gets the read_only_options of this PropertyModificationMetadata.  # noqa: E501

          # noqa: E501

        :return: The read_only_options of this PropertyModificationMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._read_only_options

    @read_only_options.setter
    def read_only_options(self, read_only_options):
        """Sets the read_only_options of this PropertyModificationMetadata.

          # noqa: E501

        :param read_only_options: The read_only_options of this PropertyModificationMetadata.  # noqa: E501
        :type read_only_options: bool
        """

        self._read_only_options = read_only_options

    @property
    def read_only_value(self):
        """Gets the read_only_value of this PropertyModificationMetadata.  # noqa: E501

          # noqa: E501

        :return: The read_only_value of this PropertyModificationMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._read_only_value

    @read_only_value.setter
    def read_only_value(self, read_only_value):
        """Sets the read_only_value of this PropertyModificationMetadata.

          # noqa: E501

        :param read_only_value: The read_only_value of this PropertyModificationMetadata.  # noqa: E501
        :type read_only_value: bool
        """
        if self.local_vars_configuration.client_side_validation and read_only_value is None:  # noqa: E501
            raise ValueError("Invalid value for `read_only_value`, must not be `None`")  # noqa: E501

        self._read_only_value = read_only_value

    @property
    def read_only_definition(self):
        """Gets the read_only_definition of this PropertyModificationMetadata.  # noqa: E501

          # noqa: E501

        :return: The read_only_definition of this PropertyModificationMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._read_only_definition

    @read_only_definition.setter
    def read_only_definition(self, read_only_definition):
        """Sets the read_only_definition of this PropertyModificationMetadata.

          # noqa: E501

        :param read_only_definition: The read_only_definition of this PropertyModificationMetadata.  # noqa: E501
        :type read_only_definition: bool
        """
        if self.local_vars_configuration.client_side_validation and read_only_definition is None:  # noqa: E501
            raise ValueError("Invalid value for `read_only_definition`, must not be `None`")  # noqa: E501

        self._read_only_definition = read_only_definition

    @property
    def archivable(self):
        """Gets the archivable of this PropertyModificationMetadata.  # noqa: E501

          # noqa: E501

        :return: The archivable of this PropertyModificationMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._archivable

    @archivable.setter
    def archivable(self, archivable):
        """Sets the archivable of this PropertyModificationMetadata.

          # noqa: E501

        :param archivable: The archivable of this PropertyModificationMetadata.  # noqa: E501
        :type archivable: bool
        """
        if self.local_vars_configuration.client_side_validation and archivable is None:  # noqa: E501
            raise ValueError("Invalid value for `archivable`, must not be `None`")  # noqa: E501

        self._archivable = archivable

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PropertyModificationMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PropertyModificationMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.hubdb.configuration import Configuration


class ImportResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"row_limit_exceeded": "bool", "duplicate_rows": "int", "rows_imported": "int", "errors": "list[Error]"}

    attribute_map = {"row_limit_exceeded": "rowLimitExceeded", "duplicate_rows": "duplicateRows", "rows_imported": "rowsImported", "errors": "errors"}

    def __init__(self, row_limit_exceeded=None, duplicate_rows=None, rows_imported=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """ImportResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._row_limit_exceeded = None
        self._duplicate_rows = None
        self._rows_imported = None
        self._errors = None
        self.discriminator = None

        self.row_limit_exceeded = row_limit_exceeded
        self.duplicate_rows = duplicate_rows
        self.rows_imported = rows_imported
        self.errors = errors

    @property
    def row_limit_exceeded(self):
        """Gets the row_limit_exceeded of this ImportResult.  # noqa: E501

        Specifies whether row limit exceeded during import  # noqa: E501

        :return: The row_limit_exceeded of this ImportResult.  # noqa: E501
        :rtype: bool
        """
        return self._row_limit_exceeded

    @row_limit_exceeded.setter
    def row_limit_exceeded(self, row_limit_exceeded):
        """Sets the row_limit_exceeded of this ImportResult.

        Specifies whether row limit exceeded during import  # noqa: E501

        :param row_limit_exceeded: The row_limit_exceeded of this ImportResult.  # noqa: E501
        :type row_limit_exceeded: bool
        """
        if self.local_vars_configuration.client_side_validation and row_limit_exceeded is None:  # noqa: E501
            raise ValueError("Invalid value for `row_limit_exceeded`, must not be `None`")  # noqa: E501

        self._row_limit_exceeded = row_limit_exceeded

    @property
    def duplicate_rows(self):
        """Gets the duplicate_rows of this ImportResult.  # noqa: E501

        Specifies number of duplicate rows  # noqa: E501

        :return: The duplicate_rows of this ImportResult.  # noqa: E501
        :rtype: int
        """
        return self._duplicate_rows

    @duplicate_rows.setter
    def duplicate_rows(self, duplicate_rows):
        """Sets the duplicate_rows of this ImportResult.

        Specifies number of duplicate rows  # noqa: E501

        :param duplicate_rows: The duplicate_rows of this ImportResult.  # noqa: E501
        :type duplicate_rows: int
        """
        if self.local_vars_configuration.client_side_validation and duplicate_rows is None:  # noqa: E501
            raise ValueError("Invalid value for `duplicate_rows`, must not be `None`")  # noqa: E501

        self._duplicate_rows = duplicate_rows

    @property
    def rows_imported(self):
        """Gets the rows_imported of this ImportResult.  # noqa: E501

        Specifies number of rows imported  # noqa: E501

        :return: The rows_imported of this ImportResult.  # noqa: E501
        :rtype: int
        """
        return self._rows_imported

    @rows_imported.setter
    def rows_imported(self, rows_imported):
        """Sets the rows_imported of this ImportResult.

        Specifies number of rows imported  # noqa: E501

        :param rows_imported: The rows_imported of this ImportResult.  # noqa: E501
        :type rows_imported: int
        """
        if self.local_vars_configuration.client_side_validation and rows_imported is None:  # noqa: E501
            raise ValueError("Invalid value for `rows_imported`, must not be `None`")  # noqa: E501

        self._rows_imported = rows_imported

    @property
    def errors(self):
        """Gets the errors of this ImportResult.  # noqa: E501

        List of errors during import  # noqa: E501

        :return: The errors of this ImportResult.  # noqa: E501
        :rtype: list[Error]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this ImportResult.

        List of errors during import  # noqa: E501

        :param errors: The errors of this ImportResult.  # noqa: E501
        :type errors: list[Error]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tickets

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.tickets.api_client import ApiClient
from hubspot.crm.tickets.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class BatchApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, batch_input_simple_public_object_id, **kwargs):  # noqa: E501
        """Archive a batch of tickets by ID  # noqa: E501

        Delete a batch of tickets by ID. Deleted tickets can be restored within 90 days of deletion. Learn more about [restoring records](https://knowledge.hubspot.com/records/restore-deleted-records).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(batch_input_simple_public_object_id, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_id: (required)
        :type batch_input_simple_public_object_id: BatchInputSimplePublicObjectId
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(batch_input_simple_public_object_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, batch_input_simple_public_object_id, **kwargs):  # noqa: E501
        """Archive a batch of tickets by ID  # noqa: E501

        Delete a batch of tickets by ID. Deleted tickets can be restored within 90 days of deletion. Learn more about [restoring records](https://knowledge.hubspot.com/records/restore-deleted-records).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(batch_input_simple_public_object_id, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_id: (required)
        :type batch_input_simple_public_object_id: BatchInputSimplePublicObjectId
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["batch_input_simple_public_object_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_simple_public_object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_simple_public_object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_simple_public_object_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_simple_public_object_id" in local_var_params:
            body_params = local_var_params["batch_input_simple_public_object_id"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/objects/tickets/batch/archive",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, batch_input_simple_public_object_batch_input_for_create, **kwargs):  # noqa: E501
        """Create a batch of tickets  # noqa: E501

        Create a batch of tickets. The `inputs` array can contain a `properties` object to define property values for the ticket, along with an `associations` array to define [associations](https://developers.hubspot.com/docs/guides/api/crm/associations/associations-v4) with other CRM records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(batch_input_simple_public_object_batch_input_for_create, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_batch_input_for_create: (required)
        :type batch_input_simple_public_object_batch_input_for_create: BatchInputSimplePublicObjectBatchInputForCreate
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSimplePublicObject
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(batch_input_simple_public_object_batch_input_for_create, **kwargs)  # noqa: E501

    def create_with_http_info(self, batch_input_simple_public_object_batch_input_for_create, **kwargs):  # noqa: E501
        """Create a batch of tickets  # noqa: E501

        Create a batch of tickets. The `inputs` array can contain a `properties` object to define property values for the ticket, along with an `associations` array to define [associations](https://developers.hubspot.com/docs/guides/api/crm/associations/associations-v4) with other CRM records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(batch_input_simple_public_object_batch_input_for_create, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_batch_input_for_create: (required)
        :type batch_input_simple_public_object_batch_input_for_create: BatchInputSimplePublicObjectBatchInputForCreate
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSimplePublicObject, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_input_simple_public_object_batch_input_for_create"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_simple_public_object_batch_input_for_create' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_simple_public_object_batch_input_for_create") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_simple_public_object_batch_input_for_create` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_simple_public_object_batch_input_for_create" in local_var_params:
            body_params = local_var_params["batch_input_simple_public_object_batch_input_for_create"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "BatchResponseSimplePublicObject",
            207: "BatchResponseSimplePublicObjectWithErrors",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/tickets/batch/create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def read(self, batch_read_input_simple_public_object_id, **kwargs):  # noqa: E501
        """Read a batch of tickets by internal ID, or unique property values  # noqa: E501

        Retrieve a batch of tickets by ID (`ticketId`) or unique property value (`idProperty`).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.read(batch_read_input_simple_public_object_id, async_req=True)
        >>> result = thread.get()

        :param batch_read_input_simple_public_object_id: (required)
        :type batch_read_input_simple_public_object_id: BatchReadInputSimplePublicObjectId
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSimplePublicObject
        """
        kwargs["_return_http_data_only"] = True
        return self.read_with_http_info(batch_read_input_simple_public_object_id, **kwargs)  # noqa: E501

    def read_with_http_info(self, batch_read_input_simple_public_object_id, **kwargs):  # noqa: E501
        """Read a batch of tickets by internal ID, or unique property values  # noqa: E501

        Retrieve a batch of tickets by ID (`ticketId`) or unique property value (`idProperty`).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.read_with_http_info(batch_read_input_simple_public_object_id, async_req=True)
        >>> result = thread.get()

        :param batch_read_input_simple_public_object_id: (required)
        :type batch_read_input_simple_public_object_id: BatchReadInputSimplePublicObjectId
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSimplePublicObject, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_read_input_simple_public_object_id", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method read" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_read_input_simple_public_object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_read_input_simple_public_object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_read_input_simple_public_object_id` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_read_input_simple_public_object_id" in local_var_params:
            body_params = local_var_params["batch_read_input_simple_public_object_id"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSimplePublicObject",
            207: "BatchResponseSimplePublicObjectWithErrors",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/tickets/batch/read",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, batch_input_simple_public_object_batch_input, **kwargs):  # noqa: E501
        """Update a batch of tickets by internal ID, or unique property values  # noqa: E501

        Update a batch of tickets by ID (`ticketId`) or unique property value (`idProperty`). Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(batch_input_simple_public_object_batch_input, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_batch_input: (required)
        :type batch_input_simple_public_object_batch_input: BatchInputSimplePublicObjectBatchInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSimplePublicObject
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(batch_input_simple_public_object_batch_input, **kwargs)  # noqa: E501

    def update_with_http_info(self, batch_input_simple_public_object_batch_input, **kwargs):  # noqa: E501
        """Update a batch of tickets by internal ID, or unique property values  # noqa: E501

        Update a batch of tickets by ID (`ticketId`) or unique property value (`idProperty`). Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(batch_input_simple_public_object_batch_input, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_batch_input: (required)
        :type batch_input_simple_public_object_batch_input: BatchInputSimplePublicObjectBatchInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSimplePublicObject, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_input_simple_public_object_batch_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_simple_public_object_batch_input' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_simple_public_object_batch_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_simple_public_object_batch_input` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_simple_public_object_batch_input" in local_var_params:
            body_params = local_var_params["batch_input_simple_public_object_batch_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSimplePublicObject",
            207: "BatchResponseSimplePublicObjectWithErrors",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/tickets/batch/update",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def upsert(self, batch_input_simple_public_object_batch_input_upsert, **kwargs):  # noqa: E501
        """Create or update a batch of tickets by unique property values  # noqa: E501

        Create or update records identified by a unique property value as specified by the `idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upsert(batch_input_simple_public_object_batch_input_upsert, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_batch_input_upsert: (required)
        :type batch_input_simple_public_object_batch_input_upsert: BatchInputSimplePublicObjectBatchInputUpsert
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSimplePublicUpsertObject
        """
        kwargs["_return_http_data_only"] = True
        return self.upsert_with_http_info(batch_input_simple_public_object_batch_input_upsert, **kwargs)  # noqa: E501

    def upsert_with_http_info(self, batch_input_simple_public_object_batch_input_upsert, **kwargs):  # noqa: E501
        """Create or update a batch of tickets by unique property values  # noqa: E501

        Create or update records identified by a unique property value as specified by the `idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upsert_with_http_info(batch_input_simple_public_object_batch_input_upsert, async_req=True)
        >>> result = thread.get()

        :param batch_input_simple_public_object_batch_input_upsert: (required)
        :type batch_input_simple_public_object_batch_input_upsert: BatchInputSimplePublicObjectBatchInputUpsert
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSimplePublicUpsertObject, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_input_simple_public_object_batch_input_upsert"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method upsert" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_simple_public_object_batch_input_upsert' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_simple_public_object_batch_input_upsert") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_simple_public_object_batch_input_upsert` when calling `upsert`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_simple_public_object_batch_input_upsert" in local_var_params:
            body_params = local_var_params["batch_input_simple_public_object_batch_input_upsert"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSimplePublicUpsertObject",
            207: "BatchResponseSimplePublicUpsertObjectWithErrors",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/tickets/batch/upsert",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.cards.configuration import Configuration


class CardObjectTypeBody(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"name": "str", "properties_to_send": "list[str]"}

    attribute_map = {"name": "name", "properties_to_send": "propertiesToSend"}

    def __init__(self, name=None, properties_to_send=None, local_vars_configuration=None):  # noqa: E501
        """CardObjectTypeBody - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._properties_to_send = None
        self.discriminator = None

        self.name = name
        self.properties_to_send = properties_to_send

    @property
    def name(self):
        """Gets the name of this CardObjectTypeBody.  # noqa: E501

        A CRM object type where this card should be displayed.  # noqa: E501

        :return: The name of this CardObjectTypeBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CardObjectTypeBody.

        A CRM object type where this card should be displayed.  # noqa: E501

        :param name: The name of this CardObjectTypeBody.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        allowed_values = ["contacts", "deals", "companies", "tickets", "marketing_events"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and name not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `name` ({0}), must be one of {1}".format(name, allowed_values))  # noqa: E501

        self._name = name

    @property
    def properties_to_send(self):
        """Gets the properties_to_send of this CardObjectTypeBody.  # noqa: E501

        An array of properties that should be sent to this card's target URL when the data fetch request is made. Must be valid properties for the corresponding CRM object type.  # noqa: E501

        :return: The properties_to_send of this CardObjectTypeBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._properties_to_send

    @properties_to_send.setter
    def properties_to_send(self, properties_to_send):
        """Sets the properties_to_send of this CardObjectTypeBody.

        An array of properties that should be sent to this card's target URL when the data fetch request is made. Must be valid properties for the corresponding CRM object type.  # noqa: E501

        :param properties_to_send: The properties_to_send of this CardObjectTypeBody.  # noqa: E501
        :type properties_to_send: list[str]
        """
        if self.local_vars_configuration.client_side_validation and properties_to_send is None:  # noqa: E501
            raise ValueError("Invalid value for `properties_to_send`, must not be `None`")  # noqa: E501

        self._properties_to_send = properties_to_send

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardObjectTypeBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CardObjectTypeBody):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CMS Url Redirects

    URL redirect operations  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.url_redirects.configuration import Configuration


class UrlMapping(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "is_trailing_slash_optional": "bool",
        "redirect_style": "int",
        "is_match_query_string": "bool",
        "created": "datetime",
        "is_match_full_url": "bool",
        "destination": "str",
        "is_only_after_not_found": "bool",
        "is_pattern": "bool",
        "precedence": "int",
        "route_prefix": "str",
        "is_protocol_agnostic": "bool",
        "id": "str",
        "updated": "datetime",
    }

    attribute_map = {
        "is_trailing_slash_optional": "isTrailingSlashOptional",
        "redirect_style": "redirectStyle",
        "is_match_query_string": "isMatchQueryString",
        "created": "created",
        "is_match_full_url": "isMatchFullUrl",
        "destination": "destination",
        "is_only_after_not_found": "isOnlyAfterNotFound",
        "is_pattern": "isPattern",
        "precedence": "precedence",
        "route_prefix": "routePrefix",
        "is_protocol_agnostic": "isProtocolAgnostic",
        "id": "id",
        "updated": "updated",
    }

    def __init__(
        self,
        is_trailing_slash_optional=None,
        redirect_style=None,
        is_match_query_string=None,
        created=None,
        is_match_full_url=None,
        destination=None,
        is_only_after_not_found=None,
        is_pattern=None,
        precedence=None,
        route_prefix=None,
        is_protocol_agnostic=None,
        id=None,
        updated=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """UrlMapping - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._is_trailing_slash_optional = None
        self._redirect_style = None
        self._is_match_query_string = None
        self._created = None
        self._is_match_full_url = None
        self._destination = None
        self._is_only_after_not_found = None
        self._is_pattern = None
        self._precedence = None
        self._route_prefix = None
        self._is_protocol_agnostic = None
        self._id = None
        self._updated = None
        self.discriminator = None

        self.is_trailing_slash_optional = is_trailing_slash_optional
        self.redirect_style = redirect_style
        self.is_match_query_string = is_match_query_string
        if created is not None:
            self.created = created
        self.is_match_full_url = is_match_full_url
        self.destination = destination
        self.is_only_after_not_found = is_only_after_not_found
        self.is_pattern = is_pattern
        self.precedence = precedence
        self.route_prefix = route_prefix
        self.is_protocol_agnostic = is_protocol_agnostic
        self.id = id
        if updated is not None:
            self.updated = updated

    @property
    def is_trailing_slash_optional(self):
        """Gets the is_trailing_slash_optional of this UrlMapping.  # noqa: E501

        Whether a trailing slash will be ignored.  # noqa: E501

        :return: The is_trailing_slash_optional of this UrlMapping.  # noqa: E501
        :rtype: bool
        """
        return self._is_trailing_slash_optional

    @is_trailing_slash_optional.setter
    def is_trailing_slash_optional(self, is_trailing_slash_optional):
        """Sets the is_trailing_slash_optional of this UrlMapping.

        Whether a trailing slash will be ignored.  # noqa: E501

        :param is_trailing_slash_optional: The is_trailing_slash_optional of this UrlMapping.  # noqa: E501
        :type is_trailing_slash_optional: bool
        """
        if self.local_vars_configuration.client_side_validation and is_trailing_slash_optional is None:  # noqa: E501
            raise ValueError("Invalid value for `is_trailing_slash_optional`, must not be `None`")  # noqa: E501

        self._is_trailing_slash_optional = is_trailing_slash_optional

    @property
    def redirect_style(self):
        """Gets the redirect_style of this UrlMapping.  # noqa: E501

        The type of redirect to create. Options include: 301 (permanent), 302 (temporary), or 305 (proxy). Find more details [here](https://knowledge.hubspot.com/cos-general/how-to-redirect-a-hubspot-page).  # noqa: E501

        :return: The redirect_style of this UrlMapping.  # noqa: E501
        :rtype: int
        """
        return self._redirect_style

    @redirect_style.setter
    def redirect_style(self, redirect_style):
        """Sets the redirect_style of this UrlMapping.

        The type of redirect to create. Options include: 301 (permanent), 302 (temporary), or 305 (proxy). Find more details [here](https://knowledge.hubspot.com/cos-general/how-to-redirect-a-hubspot-page).  # noqa: E501

        :param redirect_style: The redirect_style of this UrlMapping.  # noqa: E501
        :type redirect_style: int
        """
        if self.local_vars_configuration.client_side_validation and redirect_style is None:  # noqa: E501
            raise ValueError("Invalid value for `redirect_style`, must not be `None`")  # noqa: E501

        self._redirect_style = redirect_style

    @property
    def is_match_query_string(self):
        """Gets the is_match_query_string of this UrlMapping.  # noqa: E501

        Whether the `routePrefix` should match on the entire URL path, including the query string.  # noqa: E501

        :return: The is_match_query_string of this UrlMapping.  # noqa: E501
        :rtype: bool
        """
        return self._is_match_query_string

    @is_match_query_string.setter
    def is_match_query_string(self, is_match_query_string):
        """Sets the is_match_query_string of this UrlMapping.

        Whether the `routePrefix` should match on the entire URL path, including the query string.  # noqa: E501

        :param is_match_query_string: The is_match_query_string of this UrlMapping.  # noqa: E501
        :type is_match_query_string: bool
        """
        if self.local_vars_configuration.client_side_validation and is_match_query_string is None:  # noqa: E501
            raise ValueError("Invalid value for `is_match_query_string`, must not be `None`")  # noqa: E501

        self._is_match_query_string = is_match_query_string

    @property
    def created(self):
        """Gets the created of this UrlMapping.  # noqa: E501


        :return: The created of this UrlMapping.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this UrlMapping.


        :param created: The created of this UrlMapping.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def is_match_full_url(self):
        """Gets the is_match_full_url of this UrlMapping.  # noqa: E501

        Whether the `routePrefix` should match on the entire URL, including the domain.  # noqa: E501

        :return: The is_match_full_url of this UrlMapping.  # noqa: E501
        :rtype: bool
        """
        return self._is_match_full_url

    @is_match_full_url.setter
    def is_match_full_url(self, is_match_full_url):
        """Sets the is_match_full_url of this UrlMapping.

        Whether the `routePrefix` should match on the entire URL, including the domain.  # noqa: E501

        :param is_match_full_url: The is_match_full_url of this UrlMapping.  # noqa: E501
        :type is_match_full_url: bool
        """
        if self.local_vars_configuration.client_side_validation and is_match_full_url is None:  # noqa: E501
            raise ValueError("Invalid value for `is_match_full_url`, must not be `None`")  # noqa: E501

        self._is_match_full_url = is_match_full_url

    @property
    def destination(self):
        """Gets the destination of this UrlMapping.  # noqa: E501

        The destination URL, where the target URL should be redirected if it matches the `routePrefix`.  # noqa: E501

        :return: The destination of this UrlMapping.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this UrlMapping.

        The destination URL, where the target URL should be redirected if it matches the `routePrefix`.  # noqa: E501

        :param destination: The destination of this UrlMapping.  # noqa: E501
        :type destination: str
        """
        if self.local_vars_configuration.client_side_validation and destination is None:  # noqa: E501
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501

        self._destination = destination

    @property
    def is_only_after_not_found(self):
        """Gets the is_only_after_not_found of this UrlMapping.  # noqa: E501

        Whether the URL redirect mapping should apply only if a live page on the URL isn't found. If False, the URL redirect mapping will take precedence over any existing page.  # noqa: E501

        :return: The is_only_after_not_found of this UrlMapping.  # noqa: E501
        :rtype: bool
        """
        return self._is_only_after_not_found

    @is_only_after_not_found.setter
    def is_only_after_not_found(self, is_only_after_not_found):
        """Sets the is_only_after_not_found of this UrlMapping.

        Whether the URL redirect mapping should apply only if a live page on the URL isn't found. If False, the URL redirect mapping will take precedence over any existing page.  # noqa: E501

        :param is_only_after_not_found: The is_only_after_not_found of this UrlMapping.  # noqa: E501
        :type is_only_after_not_found: bool
        """
        if self.local_vars_configuration.client_side_validation and is_only_after_not_found is None:  # noqa: E501
            raise ValueError("Invalid value for `is_only_after_not_found`, must not be `None`")  # noqa: E501

        self._is_only_after_not_found = is_only_after_not_found

    @property
    def is_pattern(self):
        """Gets the is_pattern of this UrlMapping.  # noqa: E501

        Whether the `routePrefix` should match based on pattern.  # noqa: E501

        :return: The is_pattern of this UrlMapping.  # noqa: E501
        :rtype: bool
        """
        return self._is_pattern

    @is_pattern.setter
    def is_pattern(self, is_pattern):
        """Sets the is_pattern of this UrlMapping.

        Whether the `routePrefix` should match based on pattern.  # noqa: E501

        :param is_pattern: The is_pattern of this UrlMapping.  # noqa: E501
        :type is_pattern: bool
        """
        if self.local_vars_configuration.client_side_validation and is_pattern is None:  # noqa: E501
            raise ValueError("Invalid value for `is_pattern`, must not be `None`")  # noqa: E501

        self._is_pattern = is_pattern

    @property
    def precedence(self):
        """Gets the precedence of this UrlMapping.  # noqa: E501

        Used to prioritize URL redirection. If a given URL matches more than one redirect, the one with the **lower** precedence will be used.  # noqa: E501

        :return: The precedence of this UrlMapping.  # noqa: E501
        :rtype: int
        """
        return self._precedence

    @precedence.setter
    def precedence(self, precedence):
        """Sets the precedence of this UrlMapping.

        Used to prioritize URL redirection. If a given URL matches more than one redirect, the one with the **lower** precedence will be used.  # noqa: E501

        :param precedence: The precedence of this UrlMapping.  # noqa: E501
        :type precedence: int
        """
        if self.local_vars_configuration.client_side_validation and precedence is None:  # noqa: E501
            raise ValueError("Invalid value for `precedence`, must not be `None`")  # noqa: E501

        self._precedence = precedence

    @property
    def route_prefix(self):
        """Gets the route_prefix of this UrlMapping.  # noqa: E501

        The target incoming URL, path, or pattern to match for redirection.  # noqa: E501

        :return: The route_prefix of this UrlMapping.  # noqa: E501
        :rtype: str
        """
        return self._route_prefix

    @route_prefix.setter
    def route_prefix(self, route_prefix):
        """Sets the route_prefix of this UrlMapping.

        The target incoming URL, path, or pattern to match for redirection.  # noqa: E501

        :param route_prefix: The route_prefix of this UrlMapping.  # noqa: E501
        :type route_prefix: str
        """
        if self.local_vars_configuration.client_side_validation and route_prefix is None:  # noqa: E501
            raise ValueError("Invalid value for `route_prefix`, must not be `None`")  # noqa: E501

        self._route_prefix = route_prefix

    @property
    def is_protocol_agnostic(self):
        """Gets the is_protocol_agnostic of this UrlMapping.  # noqa: E501

        Whether the `routePrefix` should match both HTTP and HTTPS protocols.  # noqa: E501

        :return: The is_protocol_agnostic of this UrlMapping.  # noqa: E501
        :rtype: bool
        """
        return self._is_protocol_agnostic

    @is_protocol_agnostic.setter
    def is_protocol_agnostic(self, is_protocol_agnostic):
        """Sets the is_protocol_agnostic of this UrlMapping.

        Whether the `routePrefix` should match both HTTP and HTTPS protocols.  # noqa: E501

        :param is_protocol_agnostic: The is_protocol_agnostic of this UrlMapping.  # noqa: E501
        :type is_protocol_agnostic: bool
        """
        if self.local_vars_configuration.client_side_validation and is_protocol_agnostic is None:  # noqa: E501
            raise ValueError("Invalid value for `is_protocol_agnostic`, must not be `None`")  # noqa: E501

        self._is_protocol_agnostic = is_protocol_agnostic

    @property
    def id(self):
        """Gets the id of this UrlMapping.  # noqa: E501

        The unique ID of this URL redirect.  # noqa: E501

        :return: The id of this UrlMapping.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UrlMapping.

        The unique ID of this URL redirect.  # noqa: E501

        :param id: The id of this UrlMapping.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def updated(self):
        """Gets the updated of this UrlMapping.  # noqa: E501


        :return: The updated of this UrlMapping.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this UrlMapping.


        :param updated: The updated of this UrlMapping.  # noqa: E501
        :type updated: datetime
        """

        self._updated = updated

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UrlMapping):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UrlMapping):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Conversations Custom Channels

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from hubspot.conversations.custom_channels.models.public_client import PublicClient
from hubspot.conversations.custom_channels.models.public_conversations_message_attachments_inner import PublicConversationsMessageAttachmentsInner
from hubspot.conversations.custom_channels.models.public_message_status import PublicMessageStatus
from hubspot.conversations.custom_channels.models.public_recipient import PublicRecipient
from hubspot.conversations.custom_channels.models.public_sender import PublicSender
from typing import Optional, Set
from typing_extensions import Self

class PublicConversationsMessage(BaseModel):
    """
    PublicConversationsMessage
    """ # noqa: E501
    attachments: List[PublicConversationsMessageAttachmentsInner]
    subject: Optional[StrictStr] = None
    conversations_thread_id: StrictStr = Field(alias="conversationsThreadId")
    type: StrictStr
    rich_text: Optional[StrictStr] = Field(default=None, alias="richText")
    in_reply_to_id: Optional[StrictStr] = Field(default=None, alias="inReplyToId")
    created_at: datetime = Field(alias="createdAt")
    archived: StrictBool
    created_by: StrictStr = Field(alias="createdBy")
    recipients: List[PublicRecipient]
    truncation_status: StrictStr = Field(alias="truncationStatus")
    client: PublicClient
    id: StrictStr
    text: StrictStr
    channel_account_id: StrictStr = Field(alias="channelAccountId")
    senders: List[PublicSender]
    channel_id: StrictStr = Field(alias="channelId")
    updated_at: Optional[datetime] = Field(default=None, alias="updatedAt")
    status: Optional[PublicMessageStatus] = None
    direction: StrictStr
    __properties: ClassVar[List[str]] = ["attachments", "subject", "conversationsThreadId", "type", "richText", "inReplyToId", "createdAt", "archived", "createdBy", "recipients", "truncationStatus", "client", "id", "text", "channelAccountId", "senders", "channelId", "updatedAt", "status", "direction"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['MESSAGE']):
            raise ValueError("must be one of enum values ('MESSAGE')")
        return value

    @field_validator('truncation_status')
    def truncation_status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['NOT_TRUNCATED', 'TRUNCATED_TO_MOST_RECENT_REPLY', 'TRUNCATED']):
            raise ValueError("must be one of enum values ('NOT_TRUNCATED', 'TRUNCATED_TO_MOST_RECENT_REPLY', 'TRUNCATED')")
        return value

    @field_validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['INCOMING', 'OUTGOING']):
            raise ValueError("must be one of enum values ('INCOMING', 'OUTGOING')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PublicConversationsMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recipients (list)
        _items = []
        if self.recipients:
            for _item_recipients in self.recipients:
                if _item_recipients:
                    _items.append(_item_recipients.to_dict())
            _dict['recipients'] = _items
        # override the default output from pydantic by calling `to_dict()` of client
        if self.client:
            _dict['client'] = self.client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in senders (list)
        _items = []
        if self.senders:
            for _item_senders in self.senders:
                if _item_senders:
                    _items.append(_item_senders.to_dict())
            _dict['senders'] = _items
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PublicConversationsMessage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "attachments": [PublicConversationsMessageAttachmentsInner.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "subject": obj.get("subject"),
            "conversationsThreadId": obj.get("conversationsThreadId"),
            "type": obj.get("type") if obj.get("type") is not None else 'MESSAGE',
            "richText": obj.get("richText"),
            "inReplyToId": obj.get("inReplyToId"),
            "createdAt": obj.get("createdAt"),
            "archived": obj.get("archived"),
            "createdBy": obj.get("createdBy"),
            "recipients": [PublicRecipient.from_dict(_item) for _item in obj["recipients"]] if obj.get("recipients") is not None else None,
            "truncationStatus": obj.get("truncationStatus"),
            "client": PublicClient.from_dict(obj["client"]) if obj.get("client") is not None else None,
            "id": obj.get("id"),
            "text": obj.get("text"),
            "channelAccountId": obj.get("channelAccountId"),
            "senders": [PublicSender.from_dict(_item) for _item in obj["senders"]] if obj.get("senders") is not None else None,
            "channelId": obj.get("channelId"),
            "updatedAt": obj.get("updatedAt"),
            "status": PublicMessageStatus.from_dict(obj["status"]) if obj.get("status") is not None else None,
            "direction": obj.get("direction")
        })
        return _obj





# coding: utf-8

"""
    CMS Domains

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.domains.configuration import Configuration


class Domain(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "is_used_for_landing_page": "bool",
        "primary_blog_post": "bool",
        "primary_knowledge": "bool",
        "created": "datetime",
        "secondary_to_domain": "str",
        "manually_marked_as_resolving": "bool",
        "is_used_for_knowledge": "bool",
        "is_used_for_blog_post": "bool",
        "is_used_for_site_page": "bool",
        "is_resolving": "bool",
        "is_ssl_enabled": "bool",
        "is_used_for_email": "bool",
        "domain": "str",
        "primary_site_page": "bool",
        "primary_landing_page": "bool",
        "id": "str",
        "correct_cname": "str",
        "is_ssl_only": "bool",
        "updated": "datetime",
        "primary_email": "bool",
    }

    attribute_map = {
        "is_used_for_landing_page": "isUsedForLandingPage",
        "primary_blog_post": "primaryBlogPost",
        "primary_knowledge": "primaryKnowledge",
        "created": "created",
        "secondary_to_domain": "secondaryToDomain",
        "manually_marked_as_resolving": "manuallyMarkedAsResolving",
        "is_used_for_knowledge": "isUsedForKnowledge",
        "is_used_for_blog_post": "isUsedForBlogPost",
        "is_used_for_site_page": "isUsedForSitePage",
        "is_resolving": "isResolving",
        "is_ssl_enabled": "isSslEnabled",
        "is_used_for_email": "isUsedForEmail",
        "domain": "domain",
        "primary_site_page": "primarySitePage",
        "primary_landing_page": "primaryLandingPage",
        "id": "id",
        "correct_cname": "correctCname",
        "is_ssl_only": "isSslOnly",
        "updated": "updated",
        "primary_email": "primaryEmail",
    }

    def __init__(
        self,
        is_used_for_landing_page=None,
        primary_blog_post=None,
        primary_knowledge=None,
        created=None,
        secondary_to_domain=None,
        manually_marked_as_resolving=None,
        is_used_for_knowledge=None,
        is_used_for_blog_post=None,
        is_used_for_site_page=None,
        is_resolving=None,
        is_ssl_enabled=None,
        is_used_for_email=None,
        domain=None,
        primary_site_page=None,
        primary_landing_page=None,
        id=None,
        correct_cname=None,
        is_ssl_only=None,
        updated=None,
        primary_email=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Domain - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._is_used_for_landing_page = None
        self._primary_blog_post = None
        self._primary_knowledge = None
        self._created = None
        self._secondary_to_domain = None
        self._manually_marked_as_resolving = None
        self._is_used_for_knowledge = None
        self._is_used_for_blog_post = None
        self._is_used_for_site_page = None
        self._is_resolving = None
        self._is_ssl_enabled = None
        self._is_used_for_email = None
        self._domain = None
        self._primary_site_page = None
        self._primary_landing_page = None
        self._id = None
        self._correct_cname = None
        self._is_ssl_only = None
        self._updated = None
        self._primary_email = None
        self.discriminator = None

        self.is_used_for_landing_page = is_used_for_landing_page
        if primary_blog_post is not None:
            self.primary_blog_post = primary_blog_post
        if primary_knowledge is not None:
            self.primary_knowledge = primary_knowledge
        if created is not None:
            self.created = created
        if secondary_to_domain is not None:
            self.secondary_to_domain = secondary_to_domain
        if manually_marked_as_resolving is not None:
            self.manually_marked_as_resolving = manually_marked_as_resolving
        self.is_used_for_knowledge = is_used_for_knowledge
        self.is_used_for_blog_post = is_used_for_blog_post
        self.is_used_for_site_page = is_used_for_site_page
        self.is_resolving = is_resolving
        if is_ssl_enabled is not None:
            self.is_ssl_enabled = is_ssl_enabled
        self.is_used_for_email = is_used_for_email
        self.domain = domain
        if primary_site_page is not None:
            self.primary_site_page = primary_site_page
        if primary_landing_page is not None:
            self.primary_landing_page = primary_landing_page
        self.id = id
        if correct_cname is not None:
            self.correct_cname = correct_cname
        if is_ssl_only is not None:
            self.is_ssl_only = is_ssl_only
        if updated is not None:
            self.updated = updated
        if primary_email is not None:
            self.primary_email = primary_email

    @property
    def is_used_for_landing_page(self):
        """Gets the is_used_for_landing_page of this Domain.  # noqa: E501

        Whether the domain is used for CMS landing pages.  # noqa: E501

        :return: The is_used_for_landing_page of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_for_landing_page

    @is_used_for_landing_page.setter
    def is_used_for_landing_page(self, is_used_for_landing_page):
        """Sets the is_used_for_landing_page of this Domain.

        Whether the domain is used for CMS landing pages.  # noqa: E501

        :param is_used_for_landing_page: The is_used_for_landing_page of this Domain.  # noqa: E501
        :type is_used_for_landing_page: bool
        """
        if self.local_vars_configuration.client_side_validation and is_used_for_landing_page is None:  # noqa: E501
            raise ValueError("Invalid value for `is_used_for_landing_page`, must not be `None`")  # noqa: E501

        self._is_used_for_landing_page = is_used_for_landing_page

    @property
    def primary_blog_post(self):
        """Gets the primary_blog_post of this Domain.  # noqa: E501


        :return: The primary_blog_post of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._primary_blog_post

    @primary_blog_post.setter
    def primary_blog_post(self, primary_blog_post):
        """Sets the primary_blog_post of this Domain.


        :param primary_blog_post: The primary_blog_post of this Domain.  # noqa: E501
        :type primary_blog_post: bool
        """

        self._primary_blog_post = primary_blog_post

    @property
    def primary_knowledge(self):
        """Gets the primary_knowledge of this Domain.  # noqa: E501


        :return: The primary_knowledge of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._primary_knowledge

    @primary_knowledge.setter
    def primary_knowledge(self, primary_knowledge):
        """Sets the primary_knowledge of this Domain.


        :param primary_knowledge: The primary_knowledge of this Domain.  # noqa: E501
        :type primary_knowledge: bool
        """

        self._primary_knowledge = primary_knowledge

    @property
    def created(self):
        """Gets the created of this Domain.  # noqa: E501


        :return: The created of this Domain.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Domain.


        :param created: The created of this Domain.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def secondary_to_domain(self):
        """Gets the secondary_to_domain of this Domain.  # noqa: E501


        :return: The secondary_to_domain of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._secondary_to_domain

    @secondary_to_domain.setter
    def secondary_to_domain(self, secondary_to_domain):
        """Sets the secondary_to_domain of this Domain.


        :param secondary_to_domain: The secondary_to_domain of this Domain.  # noqa: E501
        :type secondary_to_domain: str
        """

        self._secondary_to_domain = secondary_to_domain

    @property
    def manually_marked_as_resolving(self):
        """Gets the manually_marked_as_resolving of this Domain.  # noqa: E501


        :return: The manually_marked_as_resolving of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._manually_marked_as_resolving

    @manually_marked_as_resolving.setter
    def manually_marked_as_resolving(self, manually_marked_as_resolving):
        """Sets the manually_marked_as_resolving of this Domain.


        :param manually_marked_as_resolving: The manually_marked_as_resolving of this Domain.  # noqa: E501
        :type manually_marked_as_resolving: bool
        """

        self._manually_marked_as_resolving = manually_marked_as_resolving

    @property
    def is_used_for_knowledge(self):
        """Gets the is_used_for_knowledge of this Domain.  # noqa: E501

        Whether the domain is used for CMS knowledge pages.  # noqa: E501

        :return: The is_used_for_knowledge of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_for_knowledge

    @is_used_for_knowledge.setter
    def is_used_for_knowledge(self, is_used_for_knowledge):
        """Sets the is_used_for_knowledge of this Domain.

        Whether the domain is used for CMS knowledge pages.  # noqa: E501

        :param is_used_for_knowledge: The is_used_for_knowledge of this Domain.  # noqa: E501
        :type is_used_for_knowledge: bool
        """
        if self.local_vars_configuration.client_side_validation and is_used_for_knowledge is None:  # noqa: E501
            raise ValueError("Invalid value for `is_used_for_knowledge`, must not be `None`")  # noqa: E501

        self._is_used_for_knowledge = is_used_for_knowledge

    @property
    def is_used_for_blog_post(self):
        """Gets the is_used_for_blog_post of this Domain.  # noqa: E501

        Whether the domain is used for CMS blog posts.  # noqa: E501

        :return: The is_used_for_blog_post of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_for_blog_post

    @is_used_for_blog_post.setter
    def is_used_for_blog_post(self, is_used_for_blog_post):
        """Sets the is_used_for_blog_post of this Domain.

        Whether the domain is used for CMS blog posts.  # noqa: E501

        :param is_used_for_blog_post: The is_used_for_blog_post of this Domain.  # noqa: E501
        :type is_used_for_blog_post: bool
        """
        if self.local_vars_configuration.client_side_validation and is_used_for_blog_post is None:  # noqa: E501
            raise ValueError("Invalid value for `is_used_for_blog_post`, must not be `None`")  # noqa: E501

        self._is_used_for_blog_post = is_used_for_blog_post

    @property
    def is_used_for_site_page(self):
        """Gets the is_used_for_site_page of this Domain.  # noqa: E501

        Whether the domain is used for CMS site pages.  # noqa: E501

        :return: The is_used_for_site_page of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_for_site_page

    @is_used_for_site_page.setter
    def is_used_for_site_page(self, is_used_for_site_page):
        """Sets the is_used_for_site_page of this Domain.

        Whether the domain is used for CMS site pages.  # noqa: E501

        :param is_used_for_site_page: The is_used_for_site_page of this Domain.  # noqa: E501
        :type is_used_for_site_page: bool
        """
        if self.local_vars_configuration.client_side_validation and is_used_for_site_page is None:  # noqa: E501
            raise ValueError("Invalid value for `is_used_for_site_page`, must not be `None`")  # noqa: E501

        self._is_used_for_site_page = is_used_for_site_page

    @property
    def is_resolving(self):
        """Gets the is_resolving of this Domain.  # noqa: E501

        Whether the DNS for this domain is optimally configured for use with HubSpot.  # noqa: E501

        :return: The is_resolving of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_resolving

    @is_resolving.setter
    def is_resolving(self, is_resolving):
        """Sets the is_resolving of this Domain.

        Whether the DNS for this domain is optimally configured for use with HubSpot.  # noqa: E501

        :param is_resolving: The is_resolving of this Domain.  # noqa: E501
        :type is_resolving: bool
        """
        if self.local_vars_configuration.client_side_validation and is_resolving is None:  # noqa: E501
            raise ValueError("Invalid value for `is_resolving`, must not be `None`")  # noqa: E501

        self._is_resolving = is_resolving

    @property
    def is_ssl_enabled(self):
        """Gets the is_ssl_enabled of this Domain.  # noqa: E501


        :return: The is_ssl_enabled of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_ssl_enabled

    @is_ssl_enabled.setter
    def is_ssl_enabled(self, is_ssl_enabled):
        """Sets the is_ssl_enabled of this Domain.


        :param is_ssl_enabled: The is_ssl_enabled of this Domain.  # noqa: E501
        :type is_ssl_enabled: bool
        """

        self._is_ssl_enabled = is_ssl_enabled

    @property
    def is_used_for_email(self):
        """Gets the is_used_for_email of this Domain.  # noqa: E501

        Whether the domain is used for CMS email web pages.  # noqa: E501

        :return: The is_used_for_email of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_for_email

    @is_used_for_email.setter
    def is_used_for_email(self, is_used_for_email):
        """Sets the is_used_for_email of this Domain.

        Whether the domain is used for CMS email web pages.  # noqa: E501

        :param is_used_for_email: The is_used_for_email of this Domain.  # noqa: E501
        :type is_used_for_email: bool
        """
        if self.local_vars_configuration.client_side_validation and is_used_for_email is None:  # noqa: E501
            raise ValueError("Invalid value for `is_used_for_email`, must not be `None`")  # noqa: E501

        self._is_used_for_email = is_used_for_email

    @property
    def domain(self):
        """Gets the domain of this Domain.  # noqa: E501

        The actual domain or sub-domain. e.g. www.hubspot.com  # noqa: E501

        :return: The domain of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this Domain.

        The actual domain or sub-domain. e.g. www.hubspot.com  # noqa: E501

        :param domain: The domain of this Domain.  # noqa: E501
        :type domain: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def primary_site_page(self):
        """Gets the primary_site_page of this Domain.  # noqa: E501


        :return: The primary_site_page of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._primary_site_page

    @primary_site_page.setter
    def primary_site_page(self, primary_site_page):
        """Sets the primary_site_page of this Domain.


        :param primary_site_page: The primary_site_page of this Domain.  # noqa: E501
        :type primary_site_page: bool
        """

        self._primary_site_page = primary_site_page

    @property
    def primary_landing_page(self):
        """Gets the primary_landing_page of this Domain.  # noqa: E501


        :return: The primary_landing_page of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._primary_landing_page

    @primary_landing_page.setter
    def primary_landing_page(self, primary_landing_page):
        """Sets the primary_landing_page of this Domain.


        :param primary_landing_page: The primary_landing_page of this Domain.  # noqa: E501
        :type primary_landing_page: bool
        """

        self._primary_landing_page = primary_landing_page

    @property
    def id(self):
        """Gets the id of this Domain.  # noqa: E501

        The unique ID of this domain.  # noqa: E501

        :return: The id of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Domain.

        The unique ID of this domain.  # noqa: E501

        :param id: The id of this Domain.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def correct_cname(self):
        """Gets the correct_cname of this Domain.  # noqa: E501


        :return: The correct_cname of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._correct_cname

    @correct_cname.setter
    def correct_cname(self, correct_cname):
        """Sets the correct_cname of this Domain.


        :param correct_cname: The correct_cname of this Domain.  # noqa: E501
        :type correct_cname: str
        """

        self._correct_cname = correct_cname

    @property
    def is_ssl_only(self):
        """Gets the is_ssl_only of this Domain.  # noqa: E501


        :return: The is_ssl_only of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._is_ssl_only

    @is_ssl_only.setter
    def is_ssl_only(self, is_ssl_only):
        """Sets the is_ssl_only of this Domain.


        :param is_ssl_only: The is_ssl_only of this Domain.  # noqa: E501
        :type is_ssl_only: bool
        """

        self._is_ssl_only = is_ssl_only

    @property
    def updated(self):
        """Gets the updated of this Domain.  # noqa: E501


        :return: The updated of this Domain.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Domain.


        :param updated: The updated of this Domain.  # noqa: E501
        :type updated: datetime
        """

        self._updated = updated

    @property
    def primary_email(self):
        """Gets the primary_email of this Domain.  # noqa: E501


        :return: The primary_email of this Domain.  # noqa: E501
        :rtype: bool
        """
        return self._primary_email

    @primary_email.setter
    def primary_email(self, primary_email):
        """Sets the primary_email of this Domain.


        :param primary_email: The primary_email of this Domain.  # noqa: E501
        :type primary_email: bool
        """

        self._primary_email = primary_email

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Domain):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Domain):
            return True

        return self.to_dict() != other.to_dict()
